/**
 * The sample package houses examples of using the various components of Ontobuilder
 */
package Sample;

import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;

import schemamatchings.ontobuilder.OntoBuilderWrapper;

import com.modica.ontobuilder.imports.ImportException;
import com.modica.ontobuilder.imports.XSDImporter;
import com.modica.ontology.Ontology;



/**
 * Class tests importers
 * 
 * @author Tomer Sagi 
 *
 */
public class ImporterTest
{
	//TODO T.S. provide a test for an exact match file as well
	
	private File inFolder;
	private File outFolder;
	/**
	 * Class constructor. Initializes input and output folder based on parameters
	 * @param inputFolder folder in which the schemas to be imported reside
	 * @param outputFolder
	 */
	public ImporterTest(File inputFolder, File outputFolder)
	{
		inFolder = inputFolder;
		outFolder = outputFolder;
	}
	/**
	 * Uses the importer to create an ontology from the file supplied
	 * @param f XSD file to import
	 * @return ontology object for ontobuilder
	 */
	private Ontology getOntologyFromFile(File f) 
	{
		OntoBuilderWrapper obw = new OntoBuilderWrapper();
		Ontology o = null;
		XSDImporter imp = new XSDImporter();
		try {
			o = imp.importFile(f);
		} catch (ImportException e) {
			
			e.printStackTrace();
		}	
		return o;
	}

	private static void printInstructions() 
	{
		System.err.println("Missing / invalid argument");
		System.out.println("Usage: java ImporterTest <inputfolderPath> <OutputFolderPath>");
		System.exit(1);
	}
	
	/**
	 * Runs an importer on all files in supplied folder path and outputs
	 * as Ontobuilder xml files to supplied output folder path
	 * 
	 * @param args 0 - inputFolderPath (absolute), 1 - outputFolderPath (absolute) 
	 */
	public static void main(String[] args)
	{
		//Check input
		if (args.length<2) printInstructions();
		File inFolder = new File(args[0]);
		if (!inFolder.isDirectory()) printInstructions();
		File outFolder = new File(args[0]);
		if (!outFolder.isDirectory()) printInstructions();
		ImporterTest it = new ImporterTest(inFolder,outFolder);
		it.convertFiles();
	}
	
	/**
	 * Imports all XSD files in the inFolder and exports them as Ontobuilder XMLs to the outFolder  
	 */
	private void convertFiles() 
	{

		XSDFilter xsdFilter = new XSDFilter();
		for (String fileName : inFolder.list(xsdFilter))
		{
			File f = new File(inFolder,fileName);
			Ontology o = getOntologyFromFile(f);
			if (o == null)
			{
				System.err.println("Failed to import file: " + fileName);
				continue;
			}
			try {
				o.saveToXML(new File(outFolder,o.getName() + ".xml"));
			} catch (IOException e) {
				System.err.println("Failed to export ontology imported from: " + fileName);
				e.printStackTrace();
			}
		}
		
	}
	
	/*
	 * Inline class XSD filter
	 */
	class XSDFilter implements FilenameFilter
	{
		public boolean accept(File dir, String name) 
		{
			if (name.substring(name.length()-4).equalsIgnoreCase(".xsd"))
				return true;
			return false;
		}	
	}
}
